pub unsafe extern "C" fn gzoffset64(file: gzFile) -> z_off64_tAvailable on crate feature
gz only.Expand description
Return the current compressed (actual) read or write offset of file. This
offset includes the count of bytes that precede the gzip stream, for example
when appending or when using gzdopen for reading. When reading, the
offset does not include as yet unused buffered input. This information can
Returns
- The number of bytes prior to the current read or write position in the compressed data stream, on success.
- -1 on error.